@@ -1,13 +1,17 @@
 import os
 import sys
 import uuid
+import math
+import json
+import random
+import base64
+import socket
+import urllib.parse
 import collections
 import contextlib
 import threading
 from typing import Generator, Optional, Any
 
-from lru import LRU
-
 import logging
 logger = logging.getLogger(__name__)
 
@@ -23,6 +27,9 @@ except ImportError:
 class System:
     """Used for the SYS default context."""
 
+    # TODO: Check user privileges before accessing SYS 
+    # TODO: Missing tests
+
     class _Env:
         def __getitem__(self, item):
             return os.getenv(item.upper())
@@ -31,86 +38,144 @@ class System:
 
     @property
     def env(self): return System._env
-    
+            
+    @property
+    def args(self): return sys.argv[1:]
+
     @property
     def now(self): return datetime.now()
 
+    @property
+    def today(self): return datetime.now().date()
+
+    @property
+    def time(self): return datetime.now().time()
+
     @property
     def uuid(self): return str(uuid.uuid4()).replace('-', '')
 
     @property
-    def pid(self): return os.getpid()
+    def rng(self): return random.random()
 
     @property
-    def cwd(self): return os.getcwd()
+    def pid(self): return os.getpid()
+
+    @property   
+    def pi(self): return math.pi
 
     @property
     def os(self): return os.name
 
+    @property
+    def arch(self): return sys.platform
+
+    @property
+    def host(self): return socket.gethostname()
+
+    @property
+    def ip(self): return socket.gethostbyname(socket.gethostname())
+
+    @property
+    def user(self): return os.getlogin()
+
+    @property
+    def home(self): return os.path.expanduser("~")
+
     @property
     def python(self): return sys.executable
 
     @property
-    def argv(self): return sys.argv
+    def py_ver(self): return sys.version
 
     @property
-    def version(self): return sys.version
+    def sig_ver(self): 
+        # TODO: Missing tests
+        with open(os.path.join(os.path.dirname(__file__), "..", "pyproject.toml")) as f:
+            return json.loads(f.read())["project"]["version"]
+        
+    @property
+    def pwd(self): return os.getcwd()
 
+    @property
+    def cwd(self): return os.getcwd()
+        
+    @property
+    def tmp(self): return os.path.join(os.getcwd(), "tmp")
 
 class ThreadLocal(threading.local):
     def __init__(self):
         # These will be the default filters and objects
         self.ctx = collections.ChainMap({
             "SYS": System(),
-            "JOIN": lambda o, s: (s or "").join(str(i) for i in o),
             "NUM": lambda x: float(x) if "." in x else int(x),
+            "UPPER": lambda x: str(x).upper(),
+            "LOWER": lambda x: str(x).lower(),
             "TRIM": lambda x: str(x).strip(),
             "STRIP": lambda x: str(x).strip(),
+            "SLUG": lambda x: str(x).replace(" ", "-"),
+            "ZFILL": lambda x, y: str(x).zfill(y),
+            "F": lambda x, *args, **kwargs: x.format(*args, **kwargs),
+            "STYLE": lambda x: dict(i.split(":") for i in x.split(";") if i),
+            "JOIN": lambda o, s: (s or "").join(str(i) for i in o),
+            "SPLIT": lambda x, y: str(x).split(y),
             "OR": lambda x, y: x or y,
             "AND": lambda x, y: x and y,
             "NOT": lambda x: not x,
             "BOOL": lambda x: bool(x),
             "INT": lambda x: int(x),
             "FLOAT": lambda x: float(x),
-            "STR": lambda x: str(x),
-            "LEN": lambda x: len(x),
             "TUPLE": lambda x: tuple(x),
             "LIST": lambda x: list(x),
             "SET": lambda x: set(x),
-            "DICT": lambda x: dict(x),
-            "REVERSE": lambda x: x[::-1],
+            "JSON": lambda x: json.dumps(x),
+            "B64": lambda x: base64.b64encode(x),
+            "B64D": lambda x: base64.b64decode(x),
+            "URL": lambda x: urllib.parse.quote(x),
+            "URLD": lambda x: urllib.parse.unquote(x),
+            "LEN": lambda x: len(x),
+            "REV": lambda x: x[::-1],
             "SORT": lambda x: sorted(x),
             "ITEM": lambda x, y: x[y],
             "KEY": lambda x, y: x[y],
+            "ATTR": lambda x, y: getattr(x, y),
             "ANY": lambda x: any(x),
             "ALL": lambda x: all(x),
+            "NONE": lambda x: not any(x),
             "SUM": lambda x: sum(x),
             "MIN": lambda x: min(x),
             "MAX": lambda x: max(x),
             "AVG": lambda x: sum(x) / len(x),
-            "FIRST": lambda x: x[0],
-            "LAST": lambda x: x[-1],
+            "ABS": lambda x: abs(x),
+            "ROUND": lambda x, y: round(x, y or 0),
+            "CEIL": lambda x: int(x) + 1,
+            "FLOOR": lambda x: int(x),
+            "TRUNC": lambda x: int(x),
+            "MOD": lambda x, y: x % y,
             "ADD": lambda x, y: x + y,
             "SUB": lambda x, y: x - y,
             "MUL": lambda x, y: x * y,
             "DIV": lambda x, y: x / y,
-            "MOD": lambda x, y: x % y,
+            "FDIV": lambda x, y: x // y,
             "EQ": lambda x, y: str(x) == str(y),
-            "NEQ": lambda x, y: str(x) != str(y),
+            "NE": lambda x, y: str(x) != str(y),
             "LT": lambda x, y: x < y,
-            "LTE": lambda x, y: x <= y,
+            "LE": lambda x, y: x <= y,
             "GT": lambda x, y: x > y,
-            "GTE": lambda x, y: x >= y,
+            "GE": lambda x, y: x >= y,
             "IN": lambda x, y: x in y,
             "CONTAINS": lambda x, y: y in x,
+            "FIRST": lambda x: x[0],
+            "LAST": lambda x: x[-1],
+            "HEAD": lambda x, y: x[:y],
+            "TAIL": lambda x, y: x[-y:],
             "TYPE": lambda x: type(x).__name__,
             "FLAT": lambda x: [i for j in x for i in j],
-            "ROUND": lambda x, y: round(x, y or 0),
-            "ABS": lambda x: abs(x),
-            "SPLIT": lambda x, y: str(x).split(y),
-            "WORD": lambda x, y: str(x).split()[y],
+            "ESC": lambda x: x.replace("\\", "\\\\").replace('"', '\\"'),
+            "UNIQ": lambda x: list(set(x)),
+            "ZIP": lambda x, y: list(zip(x, y)),
+            "SIG": lambda x: f"[[{x}]]",
+            "WORD": lambda x, y: x.split()[y],
         })
-        self.lru = LRU(128)
         # Add default context sources and thread local variables here
 
 
@@ -136,7 +201,6 @@ def local_context(*args, **kwargs) -> Generator[collections.ChainMap, None, None
             _local.ctx[key] = val
     yield _local.ctx
     _local.ctx = _local.ctx.parents
-    _local.lru.clear()
 
 
 def global_context(key: Optional[str] = None, value: Any = None) -> Any:
