@@ -1,7 +1,7 @@
 import pytest
 from dataclasses import dataclass
 
-from ..transforms import *  # Module under test
+from ..tools import *  # Module under test
 from ..errors import SigilError
 from ..contexts import local_context
 
@@ -49,32 +49,32 @@ def test_model_has_objects_attribute():
 def test_model_context_class():
     UserModel(pk=1, name="arthexis", alias="admin").save()
     with local_context(USR=UserModel):
-        assert resolve("[USR]", serializer=lambda x: x.__name__) == "UserModel"
+        assert splice("[[USR]]", serializer=lambda x: x.__name__) == "UserModel"
 
 
 def test_model_context_pk_attribute():
     UserModel(pk=1, name="arthexis", alias="admin").save()
     with local_context(USR=UserModel):
-        assert resolve("[USR=1.NAME]") == "arthexis"
+        assert splice("[[USR=1.NAME]]") == "arthexis"
 
 
 def test_model_context_pk():
     UserModel(pk=2, name="arthexis", alias="admin").save()
     with local_context(USR=UserModel):
-        assert resolve("[USR.NAME='arthexis'.PK]") == "1"
+        assert splice("[[USR.NAME='arthexis'.PK]]") == "1"
 
 
 def test_model_context_wrong_attribute():
     UserModel(pk=3, name="arthexis", alias="admin").save()
     with local_context(USR=UserModel):
         with pytest.raises(SigilError):
-            assert resolve("[USR='admin'.NAME]", on_error=OnError.RAISE)
+            assert splice("[[USR='admin'.NAME]]", on_error=OnError.RAISE)
 
 
 def test_model_context_get_by_natural_key():
     UserModel(pk=3, name="arthexis", alias="admin").save()
     with local_context(USR=UserModel):
-        assert resolve("[USR='arthexis'.ALIAS]") == 'admin'
+        assert splice("[[USR='arthexis'.ALIAS]]") == 'admin'
 
 
 # Test serializing a model using json from the standard library
@@ -82,5 +82,5 @@ def test_model_json_serialization():
     import json
     UserModel(pk=3, name="arthexis", alias="admin").save()
     with local_context(USR=UserModel):
-        assert json.loads(resolve("[USR='arthexis'.ALIAS]", serializer=json.dumps)) == 'admin'
+        assert json.loads(splice("[[USR='arthexis'.ALIAS]]", serializer=json.dumps)) == 'admin'
 
